HttpScenarioDriver<W extends ScenarioWorld> class abstract

Inheritance
Implementers

Constructors

HttpScenarioDriver()
Creates an HTTP scenario driver.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create() Future<W>
inherited
dispose(W world) Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request(W world, HttpRequestSpec request) Future<HttpResponseSpec>
Executes a logical request.
resetFixtures(W world) Future<void>
Resets project fixtures for the next scenario.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited