ZukeEvent class

Immutable runtime event emitted by a scenario.

Constructors

ZukeEvent({required String id, required String ruleId, Map<String, Object?> payload = const {}})
Creates a runtime event.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Stable event identifier.
final
payload Map<String, Object?>
Structured event payload.
final
ruleId String
Governing rule identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited