ZukeFeatureFlags class

Mutable feature-flag view used by a scenario runtime.

Constructors

ZukeFeatureFlags([Map<String, bool>? values])
Creates a flag view with optional initial values.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isEnabled(String id) bool
Returns whether the flag id is enabled.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String id, bool enabled) → void
Sets the enabled state of id.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited