EvidenceWriter class

Constructors

EvidenceWriter()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(String path, Iterable<EvidenceRecord> records, {String? buildId}) → void
writeAtomic(String directory, EvidenceRecord record, {String? buildId}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited