GherkinElement class

A parsed feature, rule, or scenario element.

Constructors

GherkinElement({required GherkinKeyword keyword, required String title, required SourceLocation source, List<GherkinTag> tags = const [], List<GherkinElement> children = const [], String? backgroundDescription, String? description})
Creates a parsed Gherkin element.
const

Properties

backgroundDescription String?
Background description, when present.
final
children List<GherkinElement>
Nested parsed elements.
final
description String?
Free-form element description.
final
hashCode int
The hash code for this object.
no setterinherited
keyword GherkinKeyword
Element keyword.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source SourceLocation
Element source location.
final
tags List<GherkinTag>
Tags attached to the element.
final
title String
Human-readable element title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited