GherkinKeyword enum

Gherkin element kinds recognized by the parser.

Inheritance
Available extensions

Values

feature → const GherkinKeyword

A feature declaration.

rule → const GherkinKeyword

A rule declaration.

scenario → const GherkinKeyword

A scenario declaration.

background → const GherkinKeyword

A background declaration.

scenarioOutline → const GherkinKeyword

A scenario outline declaration.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GherkinKeyword>
A constant List of the values in this enum, in order of their declaration.