LegacyWorkspaceConfigError class final

Raised when a workspace uses a configuration schema from an older Zuke release. The CLI maps this to its migration diagnostic.

Inheritance

Constructors

LegacyWorkspaceConfigError(String message)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited