ParsedPerformance class
A performance threshold declared by a specification.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable performance profile identifier.
final
- percentile → int
-
Percentile at which the threshold applies.
final
- profile → String
-
Profile name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → String
-
Profile execution target.
final
- threshold → String
-
Human-readable threshold expression.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited