ScenarioExampleCase class final

One executable instance of a Gherkin scenario.

A scenario without Examples has one case with empty values. A Scenario Outline has one case for every row in every Examples block. Keeping this enumeration in the core runner ensures adapters cannot accidentally run only the first row.

Constructors

ScenarioExampleCase({required int examplesIndex, required int rowIndex, required String displayLabel, required Map<String, String> values})
const

Properties

displayLabel String
final
examplesIndex int
final
hashCode int
The hash code for this object.
no setterinherited
rowIndex int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Map<String, String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited