ScenarioResult class

Implemented types

Constructors

ScenarioResult({required String executionId, required ScenarioStatus status, List<StepResult> steps = const [], required String requirementId, required String evidenceType, required String target, String variant = 'default', required String candidateId, required String profile, required String runnerId, required String runnerCompatibilityId, String? sourcePackage, String? sourceAdapter, String? sourceCompatibilityId, List<ScenarioId> scenarioIds = const [], List<String> controlIds = const [], List<String> attachmentDigests = const [], String? error})
const
ScenarioResult.fromJson(Map<String, Object?> json)
factory

Properties

attachmentDigests List<String>
final
candidateId String
final
controlIds List<String>
final
error String?
final
evidenceType String
final
executionId String
final
hashCode int
The hash code for this object.
no setterinherited
isPassed bool
no setteroverride
profile String
final
requirementId String
final
runnerCompatibilityId String
final
runnerId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scenarioIds List<ScenarioId>
final
sourceAdapter String?
final
sourceCompatibilityId String?
final
sourcePackage String?
final
status ScenarioStatus
final
steps List<StepResult>
final
target String
final
variant String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited
withSourceIdentity(ExecutionSourceIdentity identity) ScenarioResult

Operators

operator ==(Object other) bool
The equality operator.
inherited