SuiteEvidenceEmitter class final

Emits deterministic passed suite evidence for non-Gherkin test bodies.

A single assertion can substantiate several evidence types, for example a Flutter widget assertion and its corresponding Gherkin UI observation.

Constructors

SuiteEvidenceEmitter()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

emitPassing({required String requirementId, required ScenarioId scenarioId, required Iterable<String> evidenceTypes, required String target, required String runnerCompatibilityId, required String digestInput, Iterable<String> controlIds = const [], String variant = 'default', String? outputDirectory, String? profile, String? runnerId, ExecutionSourceIdentity? sourceIdentity, String? caseId}) List<File>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited