WorkspaceDiscoveryResult class
Parsed workspace data and the inputs used to produce it.
Constructors
-
WorkspaceDiscoveryResult({required ZukeConfig config, required MetadataExtractorResult data, Map<
String, String> inputContents = const {}, List<String> inputPatterns = const [], Set<String> patternInputPaths = const {}}) -
const
Properties
- config → ZukeConfig
-
Effective workspace configuration.
final
- data → MetadataExtractorResult
-
Extracted metadata and registry data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputContents
→ Map<
String, String> -
Original contents of discovered input files.
final
-
inputPatterns
→ List<
String> -
Configured workspace-relative patterns that define specification inputs.
final
-
patternInputPaths
→ Set<
String> -
Files matched from inputPatterns, excluding
zuke.yamlitself.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited