HttpResponseSpec class
HTTP response data returned by a scenario driver.
Constructors
- HttpResponseSpec({required int statusCode, Object? body, Duration latency = Duration.zero})
-
Creates a response specification.
const
Properties
- body → Object?
-
Optional decoded response body.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- latency → Duration
-
Measured request latency.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
HTTP status code.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited