CommandResult class final
Constructors
-
CommandResult({required String command, required String stage, required int exitCode, required CommandStatus status, required bool eligible, List<
Diagnostic> diagnostics = const [], Map<String, Object?> details = const {}}) -
const
-
CommandResult.fromJson(Map<
Object?, Object?> json) -
factory
Properties
- command → String
-
final
-
details
→ Map<
String, Object?> -
Additional structured command details, such as profile, stage results,
workspace results, and run identity. Raw process output is never stored.
final
-
diagnostics
→ List<
Diagnostic> -
final
- eligible → bool
-
final
- exitCode → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stage → String
-
final
- status → CommandStatus
-
final
- succeeded → bool
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited