- Implementers
Properties
-
attachmentDigests
→ List<
String> -
no setter
- candidateId → String
-
no setter
-
controlIds
→ List<
String> -
no setter
- error → String?
-
no setter
- evidenceType → String
-
no setter
- executionId → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPassed → bool
-
no setter
- profile → String
-
no setter
- requirementId → String
-
no setter
- runnerCompatibilityId → String
-
no setter
- runnerId → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scenarioIds
→ List<
ScenarioId> -
no setter
- sourceAdapter → String?
-
no setter
- sourceCompatibilityId → String?
-
no setter
- sourcePackage → String?
-
no setter
- target → String
-
no setter
- variant → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited