RunnerExecutionContext class final
Identity and output coordinates exported to a managed test process.
An entirely absent context means the test is being run as an ordinary unmanaged test. Once one Zuke variable is present, all required values must be present so evidence can never be emitted with guessed identity.
Constructors
- RunnerExecutionContext({required String resultDirectory, required String profile, required String target, required String runnerId, required String runnerCompatibilityId, required ExecutionSourceIdentity sourceIdentity})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- profile → String
-
final
- resultDirectory → String
-
final
- runnerCompatibilityId → String
-
final
- runnerId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceIdentity → ExecutionSourceIdentity
-
final
- target → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toEnvironment(
) → Map< String, String> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromEnvironment(
Map< String, String> environment) → RunnerExecutionContext?