StepParameterTypeRegistry class final
Registry for Cucumber-style parameter transformations.
Constructors
- StepParameterTypeRegistry.standard()
- Creates a registry populated with the standard parameter types.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
types
→ Iterable<
StepParameterType< Object?> > -
Registered types in declaration order.
no setter
Methods
-
define<
T> (StepParameterType< T> type) → void -
Registers
type, rejecting duplicate names. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
type<
T> (String name) → StepParameterType< T> -
Returns the registered type named
name.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited